@@ -1,13 +1,7 @@
 """OpenAPI core validation request protocols module"""
-import sys
 from typing import Optional
-
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-    from typing import runtime_checkable
-else:
-    from typing_extensions import Protocol
-    from typing_extensions import runtime_checkable
+from typing import Protocol
+from typing import runtime_checkable
 
 from openapi_core.protocols import Request
 from openapi_core.protocols import WebhookRequest
