@@ -1,14 +1,8 @@
 """OpenAPI core validation response protocols module"""
-import sys
 from typing import Iterator
 from typing import Optional
-
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-    from typing import runtime_checkable
-else:
-    from typing_extensions import Protocol
-    from typing_extensions import runtime_checkable
+from typing import Protocol
+from typing import runtime_checkable
 
 from openapi_core.protocols import Request
 from openapi_core.protocols import Response
